﻿using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class Default2 : System.Web.UI.Page
{
   
    protected void Page_Load(object sender, EventArgs e)
    {
        manufacturingUltraChart.CompositeChart.ChartLayers.Clear();
        manufacturingUltraChart.CompositeChart.Series.Clear();
        manufacturingUltraChart.CompositeChart.Legends.Clear();
        manufacturingUltraChart.Height =500;
        manufacturingUltraChart.Width = 900;
        manufacturingUltraChart.TitleTop.Text = "Charge de travail de fabrication pour la période du ";// +_FirstDateValue.ToShortDateString() + " au " + _LastDateValue.ToShortDateString();
        manufacturingUltraChart.TitleBottom.Text = "Généré le: " + DateTime.Now.ToShortDateString();

        //Build a datatable with the desired columns
        DataTable workloadTable = new DataTable();
        workloadTable.Columns.Add("Semaine", typeof(string));        //Weekly datetimes
        workloadTable.Columns.Add("HrsFabDispo", typeof(decimal));  //Manufacturing available hours --> Column layer
        workloadTable.Columns.Add("Dispo", typeof(decimal));
        workloadTable.Columns.Add("HrsFabPlanif", typeof(decimal)); //Manufacturing planned hours --> Scatter layer
        workloadTable.Columns.Add("SemaineCount", typeof(int));     //Counter for weekly datetimes to use as x axis for scatter layer

        int weekCounter = 0;

        //Fill the table from a custom weekly workload datatable
        Random rnd = new Random();
        for (int k = 0; k < 50; k++)
        {
            weekCounter = weekCounter + 1; //Week counter for use on X2 axis with scatter layer
            workloadTable.Rows.Add(new Object[] { DateTime.Today.AddDays(k).ToString(), rnd.Next(-2500, 2500), rnd.Next(-2500, 2500), rnd.Next(0, 1000), weekCounter });
        }

        //foreach (DAL.UniDataAdapters.PlanifIntegree.CapaciteProd.ChargeTravailHebdoGlobaleRow dataRow in _ChargeTravailHebdoTable)
        //{
        //    weekCounter = weekCounter + 1; //Week counter for use on X2 axis with scatter layer
        //    workloadTable.Rows.Add(new Object[] { dataRow.Semaine.ToShortDateString(), dataRow.HrsDispoFab, dataRow.HrsPlanifFabSavStock, weekCounter });
        //}

        //Composite chart type containing 2 layers
        manufacturingUltraChart.ChartType = ChartType.Composite;
        ChartArea myChartArea = new ChartArea();
        myChartArea.Bounds = new Rectangle(myChartArea.Bounds.X, myChartArea.Bounds.Y, 900, 500);
        manufacturingUltraChart.CompositeChart.ChartAreas.Add(myChartArea);

        //First X axis to be used with the column chart (series A)
        AxisItem axisX = new AxisItem();
        axisX.OrientationType = AxisNumber.X_Axis;
        axisX.DataType = AxisDataType.String;
        axisX.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
        axisX.Labels.ItemFormatString = "<ITEM_LABEL:dd/MM/yy>";
        axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
        axisX.Extent = 150;

        //Y axis to be used with both layers
        AxisItem axisY = new AxisItem();
        axisY.OrientationType = AxisNumber.Y_Axis;
        axisY.DataType = AxisDataType.Numeric;
        axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";
        axisY.RangeType = AxisRangeType.Custom;
        //Set the y axis margin to see all values
        axisY.RangeMin = 0;//-2500;// Convert.ToDouble(manufacturingChartYAxisMinValue);
        axisY.RangeMax = 2500;// Convert.ToDouble(manufacturingChartYAxisMaxValue);

        //Axis 2 to support the scatter layer with numeric data
        AxisItem axisX2 = new AxisItem();
        axisX2.OrientationType = AxisNumber.X2_Axis;
        axisX2.DataType = AxisDataType.Numeric;
        axisX2.SetLabelAxisType = SetLabelAxisType.GroupBySeries;

        //Add the axes to the chart area
        myChartArea.Axes.Add(axisX);
        myChartArea.Axes.Add(axisY);
        myChartArea.Axes.Add(axisX2);

        //First serie to display available manufacturing hours in a "column chart"
        NumericSeries seriesA = new NumericSeries();
        seriesA.Label = "HRS FAB DISPONIBLES";
        seriesA.Data.DataSource = workloadTable;
        seriesA.Data.LabelColumn = "Semaine";
        seriesA.Data.ValueColumn = "HrsFabDispo";
        seriesA.PEs.Add(new PaintElement(Color.Yellow));

        NumericSeries series2 = new NumericSeries();
        series2.Label = "lab";
        series2.Data.DataSource = workloadTable;
        series2.Data.LabelColumn = "Semaine";
        series2.Data.ValueColumn = "Dispo";
        series2.PEs.Add(new PaintElement(Color.Blue));


        //Second serie to display planned manufacturing hours in a XY series (dotted line on a scatter layer)
        XYSeries seriesB = new XYSeries();
        seriesB.Label = "HRS PLANIF FAB/SAV/STOCK";
        seriesB.Data.DataSource = workloadTable;
        seriesB.Data.LabelColumn = "Semaine";
        seriesB.Data.ValueXColumn = "SemaineCount";
        seriesB.Data.ValueYColumn = "HrsFabPlanif";
        seriesB.PEs.Add(new PaintElement(Color.Red));

        //Add the series to the chart
        manufacturingUltraChart.CompositeChart.Series.Add(seriesA);
       // manufacturingUltraChart.CompositeChart.Series.Add(series2);
        manufacturingUltraChart.CompositeChart.Series.Add(seriesB);

        //Add a layer for the column chart
        ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
        myColumnLayer.ChartType = ChartType.ColumnChart;
        myColumnLayer.ChartArea = myChartArea;
        myColumnLayer.AxisX = axisX;
        myColumnLayer.AxisY = axisY;
        myColumnLayer.Series.Add(seriesA);
        

        //ChartLayerAppearance myColumnLayer2 = new ChartLayerAppearance();
        //myColumnLayer2.ChartType = ChartType.ColumnChart;
        //myColumnLayer2.ChartArea = myChartArea;
        //myColumnLayer2.AxisX = axisX;
        //myColumnLayer2.AxisY = axisY;
        //myColumnLayer2.Series.Add(series2);
        

        //Add a layer for the scatter chart
        ChartLayerAppearance myScatterLayer = new ChartLayerAppearance();
        myScatterLayer.ChartType = ChartType.ScatterChart;
        //((ScatterChartAppearance)myScatterLayer.ChartTypeAppearance).ConnectWithLines =
        //  true;
        myScatterLayer.ChartArea = myChartArea;
        myScatterLayer.AxisX = axisX2;
        myScatterLayer.AxisY = axisY;
        myScatterLayer.Series.Add(seriesB);


        ScatterChartAppearance sca1 = new ScatterChartAppearance();
        sca1.ConnectWithLines = true;
        sca1.Icon = SymbolIcon.Circle;
        sca1.IconSize = SymbolIconSize.Small;
        myScatterLayer.ChartTypeAppearance = sca1; 




        //Add the layers to the chart
        manufacturingUltraChart.CompositeChart.ChartLayers.Add(myColumnLayer);
       // manufacturingUltraChart.CompositeChart.ChartLayers.Add(myColumnLayer2);
        manufacturingUltraChart.CompositeChart.ChartLayers.Add(myScatterLayer);

        //Add a legend for the scatter layer (planned manufacturing hours)
        CompositeLegend myLegend = new CompositeLegend();
        myLegend.ChartLayers.Add(myScatterLayer);
        myLegend.Bounds = new Rectangle(90, 0, 10, 5);
        myLegend.BoundsMeasureType = MeasureType.Percentage;
        myLegend.PE.ElementType = PaintElementType.Gradient;
        myLegend.PE.FillGradientStyle = GradientStyle.ForwardDiagonal;
        myLegend.PE.Fill = Color.CornflowerBlue;
        myLegend.PE.FillStopColor = Color.Transparent;
        myLegend.Border.CornerRadius = 10;
        myLegend.Border.Thickness = 0;
        manufacturingUltraChart.CompositeChart.Legends.Add(myLegend);

        

    }
    protected void manufacturingUltraChart_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
    {

        //List<Box> listBox = new List<Box>();
        //foreach (Primitive item in e.SceneGraph)
        //{
        //    Box pl = item as Box;
        //    if (pl != null && pl.Series != null && pl.Layer.LayerID == "chartLayer2")
        //    {
        //        pl.rect = new Rectangle(pl.rect.X + (pl.rect.Width / 2) , pl.rect.Y, pl.rect.Width - (pl.rect.Width / 2), pl.rect.Height);

        //    }
        //    if (pl != null && pl.Series != null && pl.Layer.LayerID == "chartLayer1")
        //    {
        //        listBox.Add(pl);
        //        pl.rect = new Rectangle(pl.rect.X, pl.rect.Y, pl.rect.Width - (pl.rect.Width / 2), pl.rect.Height);
        //    }


        //    // Polyline primitive represent your line chart (build it from your scatter points). The Polyline primitive contains many points, that`s why I`m using loop to get X and Y coordinates of each point.
        //    Polyline line = item as Polyline;
        //    if (line != null)
        //    {
        //        int k = 0;
        //        foreach (DataPoint pp in line.points)
        //        {
        //            // I set new X coordinate for each point from Polyline primitive. To be correct our X coordinate, I`m using the X coordinate of our currect Box primitive. Also I take care about the width of the columns, so we should include this code: (listBox[k].rect.Width / 2);
        //            pp.point.X = listBox[k].rect.X + (listBox[k].rect.Width);
        //            k++;
        //        }
        //    }
        //}

    }
}